@@ -1,5 +1,6 @@
 # pylint: disable=too-many-lines
 import logging
+from enum import Enum
 from pathlib import Path
 from typing import Dict, List, Optional
 
@@ -15,6 +16,12 @@ from bokeh.plotting import ColumnDataSource, figure
 logger = logging.getLogger(__name__)
 
 
+class OutputTarget(Enum):
+    ANNOTATION = "annotation"
+    INPUT_DATA = "input_data"
+    TASK = "task"
+
+
 class LineGraph:
     """
     グラフを出力するクラス
@@ -168,9 +175,9 @@ class LineGraph:
 
         """
         max_user_length = len(self.my_palette)
-        tmp_user_id_list: List[str] = df.sort_values(by=datetime_column, ascending=False)[
-            user_id_column
-        ].dropna().unique().tolist()
+        tmp_user_id_list: List[str] = (
+            df.sort_values(by=datetime_column, ascending=False)[user_id_column].dropna().unique().tolist()
+        )
 
         if arg_user_id_list is None or len(arg_user_id_list) == 0:
             user_id_list = tmp_user_id_list
@@ -183,7 +190,9 @@ class LineGraph:
         return user_id_list[0:max_user_length]
 
     def write_productivity_line_graph_for_annotator(
-        self, df: pandas.DataFrame, first_annotation_user_id_list: Optional[List[str]] = None,
+        self,
+        df: pandas.DataFrame,
+        first_annotation_user_id_list: Optional[List[str]] = None,
     ):
         """
         生産性を教師付作業者ごとにプロットする。
@@ -222,7 +231,7 @@ class LineGraph:
                     )
                 )
 
-            for user_index, user_id in enumerate(first_annotation_user_id_list):  # type: ignore
+            for user_index, user_id in enumerate(user_id_list):
                 filtered_df = df[df["first_annotation_user_id"] == user_id]
                 if filtered_df.empty:
                     logger.debug(f"dataframe is empty. user_id = {user_id}")
@@ -268,13 +277,13 @@ class LineGraph:
             logger.info("データが0件のため出力しない")
             return
 
-        first_annotation_user_id_list = self.create_user_id_list(
+        user_id_list = self.create_user_id_list(
             df,
             "first_annotation_user_id",
             datetime_column="first_annotation_started_date",
             arg_user_id_list=first_annotation_user_id_list,
         )
-        logger.debug(f"教師付者用の折れ線グラフに表示する、教師付者のuser_id = {first_annotation_user_id_list}")
+        logger.debug(f"教師付者用の折れ線グラフに表示する、教師付者のuser_id = {user_id_list}")
 
         df["date_first_annotation_started_date"] = df["first_annotation_started_date"].map(
             lambda e: dateutil.parser.parse(e).date()
@@ -318,7 +327,8 @@ class LineGraph:
             ),
         ]
         write_cumulative_graph(
-            fig_info_list_annotation_count, html_title="折れ線-横軸_教師付開始日-縦軸_アノテーションあたりの指標-教師付者用",
+            fig_info_list_annotation_count,
+            html_title="折れ線-横軸_教師付開始日-縦軸_アノテーションあたりの指標-教師付者用",
         )
 
         fig_info_list_input_data_count = [
@@ -400,13 +410,17 @@ class LineGraph:
         write_cumulative_graph(fig_info_list_value, html_title="折れ線-横軸_教師付開始日-縦軸_指標-教師付者用")
 
     def write_cumulative_line_graph_for_annotator(
-        self, df: pandas.DataFrame, first_annotation_user_id_list: Optional[List[str]] = None,
+        self,
+        df: pandas.DataFrame,
+        output_target_list: Optional[List[OutputTarget]] = None,
+        first_annotation_user_id_list: Optional[List[str]] = None,
     ):
         """
         教師付作業者用の累積折れ線グラフを出力する。
 
         Args:
             df:
+            output_target_list: すべて出力する
             first_annotation_user_id_list: 最初のアノテーションを担当したuser_idのList. Noneの場合はtask_dfから決まる。
 
         Returns:
@@ -439,7 +453,7 @@ class LineGraph:
                     )
                 )
 
-            for user_index, user_id in enumerate(first_annotation_user_id_list):  # type: ignore
+            for user_index, user_id in enumerate(user_id_list):
                 filtered_df = df[df["first_annotation_user_id"] == user_id]
                 if filtered_df.empty:
                     logger.debug(f"dataframe is empty. user_id = {user_id}")
@@ -487,143 +501,149 @@ class LineGraph:
             logger.info("タスク一覧が0件のため出力しない")
             return
 
-        first_annotation_user_id_list = self.create_user_id_list(
+        user_id_list = self.create_user_id_list(
             df,
             "first_annotation_user_id",
             datetime_column="first_annotation_started_datetime",
             arg_user_id_list=first_annotation_user_id_list,
         )
-        logger.debug(f"教師付者用の累積折れ線グラフに表示する、教師付者のuser_id = {first_annotation_user_id_list}")
+        logger.debug(f"教師付者用の累積折れ線グラフに表示する、教師付者のuser_id = {user_id_list}")
 
-        # 横軸が累計のアノテーション数
-        fig_info_list_annotation_count = [
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_annotation_worktime_hour",
-                title="アノテーション数と教師付時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="教師付時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_first_annotation_worktime_hour",
-                title="アノテーション数と1回目の教師付時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="1回目の教師付時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_inspection_worktime_hour",
-                title="アノテーション数と検査時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="アノテーション数と受入時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_inspection_count",
-                title="アノテーション数と検査コメント数の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="検査コメント数",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-教師付者用")
+        if output_target_list is None or OutputTarget.ANNOTATION in output_target_list:
+            # 横軸が累計のアノテーション数
+            fig_info_list_annotation_count = [
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_annotation_worktime_hour",
+                    title="アノテーション数と教師付時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="教師付時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_first_annotation_worktime_hour",
+                    title="アノテーション数と1回目の教師付時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="1回目の教師付時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="アノテーション数と検査時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="アノテーション数と受入時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_inspection_count",
+                    title="アノテーション数と検査コメント数の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="検査コメント数",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-教師付者用")
 
-        # 横軸が累計の入力データ数
-        fig_info_list_input_data_count = [
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_annotation_worktime_hour",
-                title="入力データ数と教師付時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="教師付時間[hour]",
-            ),
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_inspection_worktime_hour",
-                title="入力データ数と検査時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="入力データ数と受入時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_inspection_count",
-                title="アノテーション数と検査コメント数の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="検査コメント数",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-教師付者用")
+        if output_target_list is None or OutputTarget.INPUT_DATA in output_target_list:
+            # 横軸が累計の入力データ数
+            fig_info_list_input_data_count = [
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_annotation_worktime_hour",
+                    title="入力データ数と教師付時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="教師付時間[hour]",
+                ),
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="入力データ数と検査時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="入力データ数と受入時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_inspection_count",
+                    title="アノテーション数と検査コメント数の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="検査コメント数",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-教師付者用")
 
-        # 横軸が累計のタスク数
-        fig_info_list_task_count = [
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_annotation_worktime_hour",
-                title="タスク数と教師付時間の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="教師付時間[hour]",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_inspection_worktime_hour",
-                title="タスク数と検査時間の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="タスク数と受入時間の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_inspection_count",
-                title="タスク数と検査コメント数の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="検査コメント数",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_number_of_rejections",
-                title="タスク数と差し戻し回数の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="差し戻し回数",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_number_of_rejections_by_inspection",
-                title="タスク数と差し戻し回数(検査フェーズ)の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="差し戻し回数(検査フェーズ)",
-            ),
-            dict(
-                x="cumulative_task_count",
-                y="cumulative_number_of_rejections_by_acceptance",
-                title="タスク数と差し戻し回数(受入フェーズ)の累積グラフ",
-                x_axis_label="タスク数",
-                y_axis_label="差し戻し回数(受入フェーズ)",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_task_count, html_title="累積折れ線-横軸_タスク数-教師付者用")
+        if output_target_list is None or OutputTarget.TASK in output_target_list:
+            # 横軸が累計のタスク数
+            fig_info_list_task_count = [
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_annotation_worktime_hour",
+                    title="タスク数と教師付時間の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="教師付時間[hour]",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="タスク数と検査時間の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="タスク数と受入時間の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_inspection_count",
+                    title="タスク数と検査コメント数の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="検査コメント数",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_number_of_rejections",
+                    title="タスク数と差し戻し回数の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="差し戻し回数",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_number_of_rejections_by_inspection",
+                    title="タスク数と差し戻し回数(検査フェーズ)の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="差し戻し回数(検査フェーズ)",
+                ),
+                dict(
+                    x="cumulative_task_count",
+                    y="cumulative_number_of_rejections_by_acceptance",
+                    title="タスク数と差し戻し回数(受入フェーズ)の累積グラフ",
+                    x_axis_label="タスク数",
+                    y_axis_label="差し戻し回数(受入フェーズ)",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_task_count, html_title="累積折れ線-横軸_タスク数-教師付者用")
 
     def write_cumulative_line_graph_for_inspector(
-        self, df: pandas.DataFrame, first_inspection_user_id_list: Optional[List[str]] = None,
+        self,
+        df: pandas.DataFrame,
+        output_target_list: Optional[List[OutputTarget]] = None,
+        first_inspection_user_id_list: Optional[List[str]] = None,
     ):
         """
         検査作業者用の累積折れ線グラフを出力する。
@@ -662,7 +682,7 @@ class LineGraph:
                     )
                 )
 
-            for user_index, user_id in enumerate(first_inspection_user_id_list):  # type: ignore
+            for user_index, user_id in enumerate(user_id_list):
                 filtered_df = df[df["first_inspection_user_id"] == user_id]
                 if filtered_df.empty:
                     logger.debug(f"dataframe is empty. user_id = {user_id}")
@@ -711,73 +731,78 @@ class LineGraph:
             logger.info("タスク一覧が0件のため出力しない")
             return
 
-        first_inspection_user_id_list = self.create_user_id_list(
+        user_id_list = self.create_user_id_list(
             df,
             "first_inspection_user_id",
             datetime_column="first_inspection_started_datetime",
             arg_user_id_list=first_inspection_user_id_list,
         )
 
-        if len(first_inspection_user_id_list) == 0:
+        if len(user_id_list) == 0:
             logger.info(f"検査フェーズを担当してユーザがいないため、検査者用のグラフは出力しません。")
             return
 
-        logger.debug(f"検査者用の累積折れ線グラフに表示する、検査者のuser_id = {first_inspection_user_id_list}")
+        logger.debug(f"検査者用の累積折れ線グラフに表示する、検査者のuser_id = {user_id_list}")
 
-        # 横軸が累計のアノテーション数
-        fig_info_list_annotation_count = [
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_first_inspection_worktime_hour",
-                title="アノテーション数と1回目検査時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="1回目の検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_inspection_worktime_hour",
-                title="アノテーション数と検査時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_inspection_count",
-                y="cumulative_first_inspection_worktime_hour",
-                title="検査コメント数と1回目検査時間の累積グラフ",
-                x_axis_label="検査コメント数",
-                y_axis_label="1回目の検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_inspection_count",
-                y="cumulative_inspection_worktime_hour",
-                title="検査コメント数と検査時間の累積グラフ",
-                x_axis_label="検査コメント数",
-                y_axis_label="検査時間[hour]",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-検査者用")
+        if output_target_list is None or OutputTarget.ANNOTATION in output_target_list:
+            # 横軸が累計のアノテーション数
+            fig_info_list_annotation_count = [
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_first_inspection_worktime_hour",
+                    title="アノテーション数と1回目検査時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="1回目の検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="アノテーション数と検査時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_inspection_count",
+                    y="cumulative_first_inspection_worktime_hour",
+                    title="検査コメント数と1回目検査時間の累積グラフ",
+                    x_axis_label="検査コメント数",
+                    y_axis_label="1回目の検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_inspection_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="検査コメント数と検査時間の累積グラフ",
+                    x_axis_label="検査コメント数",
+                    y_axis_label="検査時間[hour]",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-検査者用")
 
-        # 横軸が累計の入力データ数
-        fig_info_list_input_data_count = [
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_first_inspection_worktime_hour",
-                title="入力データ数と1回目検査時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="1回目の検査時間[hour]",
-            ),
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_inspection_worktime_hour",
-                title="入力データ数と検査時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="検査時間[hour]",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-検査者用")
+        if output_target_list is None or OutputTarget.INPUT_DATA in output_target_list:
+            # 横軸が累計の入力データ数
+            fig_info_list_input_data_count = [
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_first_inspection_worktime_hour",
+                    title="入力データ数と1回目検査時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="1回目の検査時間[hour]",
+                ),
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_inspection_worktime_hour",
+                    title="入力データ数と検査時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="検査時間[hour]",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-検査者用")
 
     def write_cumulative_line_graph_for_acceptor(
-        self, df: pandas.DataFrame, first_acceptance_user_id_list: Optional[List[str]] = None,
+        self,
+        df: pandas.DataFrame,
+        output_target_list: Optional[List[OutputTarget]] = None,
+        first_acceptance_user_id_list: Optional[List[str]] = None,
     ):
         """
         受入者用の累積折れ線グラフを出力する。
@@ -816,7 +841,7 @@ class LineGraph:
                     )
                 )
 
-            for user_index, user_id in enumerate(first_acceptance_user_id_list):  # type: ignore
+            for user_index, user_id in enumerate(user_id_list):
                 filtered_df = df[df["first_acceptance_user_id"] == user_id]
                 if filtered_df.empty:
                     logger.debug(f"dataframe is empty. user_id = {user_id}")
@@ -867,70 +892,72 @@ class LineGraph:
             logger.info("タスク一覧が0件のため出力しない")
             return
 
-        first_acceptance_user_id_list = self.create_user_id_list(
+        user_id_list = self.create_user_id_list(
             df,
             "first_acceptance_user_id",
             datetime_column="first_acceptance_started_datetime",
             arg_user_id_list=first_acceptance_user_id_list,
         )
 
-        if len(first_acceptance_user_id_list) == 0:
+        if len(user_id_list) == 0:
             logger.info(f"受入フェーズを担当してユーザがいないため、受入者用のグラフは出力しません。")
             return
 
-        logger.debug(f"受入者用の累積折れ線グラフに表示する、受入者のuser_id = {first_acceptance_user_id_list}")
+        logger.debug(f"受入者用の累積折れ線グラフに表示する、受入者のuser_id = {user_id_list}")
 
-        # 横軸が累計のアノテーション数
-        fig_info_list_annotation_count = [
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_first_acceptance_worktime_hour",
-                title="アノテーション数と1回目受入時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="1回目の受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_annotation_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="アノテーション数と受入時間の累積グラフ",
-                x_axis_label="アノテーション数",
-                y_axis_label="受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_inspection_count",
-                y="cumulative_first_acceptance_worktime_hour",
-                title="検査コメント数と1回目受入時間の累積グラフ",
-                x_axis_label="検査コメント数",
-                y_axis_label="1回目の受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_inspection_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="検査コメント数と受入時間の累積グラフ",
-                x_axis_label="検査コメント数",
-                y_axis_label="受入時間[hour]",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-受入者用")
+        if output_target_list is None or OutputTarget.ANNOTATION in output_target_list:
+            # 横軸が累計のアノテーション数
+            fig_info_list_annotation_count = [
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_first_acceptance_worktime_hour",
+                    title="アノテーション数と1回目受入時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="1回目の受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_annotation_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="アノテーション数と受入時間の累積グラフ",
+                    x_axis_label="アノテーション数",
+                    y_axis_label="受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_inspection_count",
+                    y="cumulative_first_acceptance_worktime_hour",
+                    title="検査コメント数と1回目受入時間の累積グラフ",
+                    x_axis_label="検査コメント数",
+                    y_axis_label="1回目の受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_inspection_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="検査コメント数と受入時間の累積グラフ",
+                    x_axis_label="検査コメント数",
+                    y_axis_label="受入時間[hour]",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_annotation_count, html_title="累積折れ線-横軸_アノテーション数-受入者用")
 
-        # 横軸が累計の入力データ数
-        fig_info_list_input_data_count = [
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_first_acceptance_worktime_hour",
-                title="入力データ数と1回目受入時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="1回目の受入時間[hour]",
-            ),
-            dict(
-                x="cumulative_input_data_count",
-                y="cumulative_acceptance_worktime_hour",
-                title="入力データ数と受入時間の累積グラフ",
-                x_axis_label="入力データ数",
-                y_axis_label="受入時間[hour]",
-            ),
-        ]
-        write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-受入者用")
+        if output_target_list is None or OutputTarget.INPUT_DATA in output_target_list:
+            # 横軸が累計の入力データ数
+            fig_info_list_input_data_count = [
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_first_acceptance_worktime_hour",
+                    title="入力データ数と1回目受入時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="1回目の受入時間[hour]",
+                ),
+                dict(
+                    x="cumulative_input_data_count",
+                    y="cumulative_acceptance_worktime_hour",
+                    title="入力データ数と受入時間の累積グラフ",
+                    x_axis_label="入力データ数",
+                    y_axis_label="受入時間[hour]",
+                ),
+            ]
+            write_cumulative_graph(fig_info_list_input_data_count, html_title="累積折れ線-横軸_入力データ数-受入者用")
 
     def write_cumulative_line_graph_by_date(
         self, df: pandas.DataFrame, user_id_list: Optional[List[str]] = None
@@ -992,7 +1019,7 @@ class LineGraph:
                 )
             )
 
-        for user_index, user_id in enumerate(user_id_list):  # type: ignore
+        for user_index, user_id in enumerate(user_id_list):
             filtered_df = df[df["user_id"] == user_id]
             if filtered_df.empty:
                 logger.debug(f"dataframe is empty. user_id = {user_id}")
@@ -1136,7 +1163,13 @@ class LineGraph:
         def create_task_figure():
             y_range_name = "worktime_axis"
             fig_task = create_figure(title="日ごとのタスク数と作業時間", y_axis_label="タスク数")
-            fig_task.add_layout(LinearAxis(y_range_name=y_range_name, axis_label="作業時間[hour]",), "right")
+            fig_task.add_layout(
+                LinearAxis(
+                    y_range_name=y_range_name,
+                    axis_label="作業時間[hour]",
+                ),
+                "right",
+            )
             y_overlimit = 0.05
             fig_task.extra_y_ranges = {
                 y_range_name: DataRange1d(end=df["actual_worktime_hour"].max() * (1 + y_overlimit))
@@ -1161,7 +1194,13 @@ class LineGraph:
         def create_input_data_figure():
             y_range_name = "worktime_axis"
             fig_input_data = create_figure(title="日ごとの入力データ数と作業時間", y_axis_label="入力データ数")
-            fig_input_data.add_layout(LinearAxis(y_range_name=y_range_name, axis_label="作業時間[hour]",), "right")
+            fig_input_data.add_layout(
+                LinearAxis(
+                    y_range_name=y_range_name,
+                    axis_label="作業時間[hour]",
+                ),
+                "right",
+            )
             y_overlimit = 0.05
             fig_input_data.extra_y_ranges = {
                 y_range_name: DataRange1d(end=df["actual_worktime_hour"].max() * (1 + y_overlimit))
@@ -1195,9 +1234,9 @@ class LineGraph:
 
         fig_list = [
             create_figure(title="日ごとの作業時間", y_axis_label="作業時間[hour]"),
-            create_figure(title="日ごとのタスクあたり作業時間", y_axis_label="タスクあたり作業時間[task/hour]"),
-            create_figure(title="日ごとの入力データあたり作業時間", y_axis_label="入力データあたり作業時間[input_data/hour]"),
-            create_figure(title="日ごとのアノテーションあたり作業時間", y_axis_label="アノテーションあたり作業時間[annotation/hour]"),
+            create_figure(title="日ごとのタスクあたり作業時間", y_axis_label="タスクあたり作業時間[hour/task]"),
+            create_figure(title="日ごとの入力データあたり作業時間", y_axis_label="入力データあたり作業時間[hour/input_data]"),
+            create_figure(title="日ごとのアノテーションあたり作業時間", y_axis_label="アノテーションあたり作業時間[hour/annotation]"),
         ]
 
         fig_info_list = [
@@ -1289,6 +1328,82 @@ class LineGraph:
                 y_axis_label=y_axis_label,
             )
 
+        def create_task_figure():
+            y_range_name = "worktime_axis"
+            fig = create_figure(title="日ごとの累積タスク数と累積作業時間", y_axis_label="タスク数")
+            fig.add_layout(
+                LinearAxis(
+                    y_range_name=y_range_name,
+                    axis_label="作業時間[hour]",
+                ),
+                "right",
+            )
+            y_overlimit = 0.05
+            fig.extra_y_ranges = {
+                y_range_name: DataRange1d(end=df["cumsum_actual_worktime_hour"].max() * (1 + y_overlimit))
+            }
+
+            # 値をプロット
+            self._plot_line_and_circle(
+                fig,
+                x_column_name=x_column_name,
+                y_column_name="cumsum_task_count",
+                source=source,
+                color=self.my_small_palette[0],
+                legend_label="タスク数",
+            )
+
+            # 値をプロット
+            self._plot_line_and_circle(
+                fig,
+                x_column_name=x_column_name,
+                y_column_name="cumsum_actual_worktime_hour",
+                source=source,
+                color=self.my_small_palette[1],
+                legend_label="実績作業時間",
+                y_range_name=y_range_name,
+            )
+
+            return fig
+
+        def create_input_data_figure():
+            y_range_name = "worktime_axis"
+            fig = create_figure(title="日ごとの累積入力データ数と累積作業時間", y_axis_label="入力データ数")
+            fig.add_layout(
+                LinearAxis(
+                    y_range_name=y_range_name,
+                    axis_label="作業時間[hour]",
+                ),
+                "right",
+            )
+            y_overlimit = 0.05
+            fig.extra_y_ranges = {
+                y_range_name: DataRange1d(end=df["cumsum_actual_worktime_hour"].max() * (1 + y_overlimit))
+            }
+
+            # 値をプロット
+            self._plot_line_and_circle(
+                fig,
+                x_column_name=x_column_name,
+                y_column_name="cumsum_input_data_count",
+                source=source,
+                color=self.my_small_palette[0],
+                legend_label="入力データ数",
+            )
+
+            # 値をプロット
+            self._plot_line_and_circle(
+                fig,
+                x_column_name=x_column_name,
+                y_column_name="cumsum_actual_worktime_hour",
+                source=source,
+                color=self.my_small_palette[1],
+                legend_label="実績作業時間",
+                y_range_name=y_range_name,
+            )
+
+            return fig
+
         if len(df) == 0:
             logger.info("データが0件のため出力しない")
             return
@@ -1301,14 +1416,10 @@ class LineGraph:
         logger.debug(f"{output_file} を出力します。")
 
         fig_list = [
-            create_figure(title="日ごとの累積タスク数", y_axis_label="タスク数"),
-            create_figure(title="日ごとの累積入力データ数", y_axis_label="入力データ数"),
             create_figure(title="日ごとの累積作業時間", y_axis_label="作業時間[hour]"),
         ]
 
         fig_info_list = [
-            {"x": "dt_date", "y_info_list": [{"column": "cumsum_task_count", "legend": "タスク数"}]},
-            {"x": "dt_date", "y_info_list": [{"column": "cumsum_input_data_count", "legend": "入力データ数"}]},
             {
                 "x": "dt_date",
                 "y_info_list": [
@@ -1348,6 +1459,10 @@ class LineGraph:
             "cumsum_monitored_worktime_hour",
         ]
         hover_tool = self._create_hover_tool(tooltip_item)
+
+        fig_list.insert(0, create_task_figure())
+        fig_list.insert(1, create_input_data_figure())
+
         for fig in fig_list:
             self._set_legend(fig, hover_tool)
 
