@@ -1,8 +1,10 @@
 import argparse
 import logging
-import time
+import multiprocessing
+import sys
 import uuid
-from typing import Any, Dict, List, Optional
+from functools import partial
+from typing import Any, Dict, List, Optional, Tuple
 
 import annofabapi
 import annofabapi.utils
@@ -12,19 +14,28 @@ from annofabapi.models import InputDataType, ProjectMemberRole, TaskPhase, TaskS
 import annofabcli
 import annofabcli.common.cli
 from annofabcli import AnnofabApiFacade
-from annofabcli.common.cli import AbstractCommandLineInterface, ArgumentParser, build_annofabapi_resource_and_login
+from annofabcli.common.cli import (
+    AbstracCommandCinfirmInterface,
+    AbstractCommandLineInterface,
+    ArgumentParser,
+    build_annofabapi_resource_and_login,
+)
 
 logger = logging.getLogger(__name__)
 
 
-class RejectTasks(AbstractCommandLineInterface):
+class RejectTasksMain(AbstracCommandCinfirmInterface):
+    def __init__(self, service: annofabapi.Resource, all_yes: bool = False):
+        self.service = service
+        self.facade = AnnofabApiFacade(service)
+        AbstracCommandCinfirmInterface.__init__(self, all_yes)
+
     def add_inspection_comment(
         self,
         project_id: str,
         project_input_data_type: InputDataType,
         task: Dict[str, Any],
         inspection_comment: str,
-        commenter_account_id: str,
     ):
         """
         検査コメントを付与する。
@@ -36,7 +47,6 @@ class RejectTasks(AbstractCommandLineInterface):
             project_input_data_type: プロジェクトの入力データの種類
             task:
             inspection_comment:
-            commenter_account_id:
 
         Returns:
             更新した検査コメントの一覧
@@ -57,10 +67,10 @@ class RejectTasks(AbstractCommandLineInterface):
                     "input_data_id": first_input_data_id,
                     "inspection_id": str(uuid.uuid4()),
                     "phase": task["phase"],
-                    "commenter_account_id": commenter_account_id,
+                    "commenter_account_id": self.service.api.account_id,
                     "data": inspection_data,
                     "status": "annotator_action_required",
-                    "created_datetime": annofabapi.utils.str_now(),
+                    "created_datetime": task["updated_datetime"],
                 },
                 "_type": "Put",
             }
@@ -81,27 +91,35 @@ class RejectTasks(AbstractCommandLineInterface):
         else:
             confirm_message += f"担当者は割り当てません。"
 
-        return self.confirm_processing_task(task_id, confirm_message)
+        return self.confirm_processing(confirm_message)
+
+    def change_to_working_status(self, project_id: str, task: Dict[str, Any]) -> Dict[str, Any]:
+        """
+        作業中状態に遷移する。必要ならば担当者を自分自身に変更する。
+
+        Args:
+            project_id:
+            task:
+
+        Returns:
+            作業中状態遷移後のタスク
+        """
 
-    def change_to_working_status(self, project_id: str, task: Dict[str, Any], my_account_id: str) -> bool:
-        # 担当者変更
-        changed_operator = False
         task_id = task["task_id"]
         try:
-            if task["account_id"] != my_account_id:
-                self.facade.change_operator_of_task(project_id, task_id, my_account_id)
-                changed_operator = True
+            if task["account_id"] != self.service.api.account_id:
+                self.facade.change_operator_of_task(project_id, task_id, self.service.api.account_id)
                 logger.debug(f"{task_id}: 担当者を自分自身に変更しました。")
 
-            self.facade.change_to_working_status(project_id, task_id, my_account_id)
-            return changed_operator
+            changed_task = self.facade.change_to_working_status(project_id, task_id, self.service.api.account_id)
+            return changed_task
 
         except requests.HTTPError as e:
             logger.warning(e)
             logger.warning(f"{task_id}: 担当者の変更、または作業中状態への変更に失敗しました。")
             raise
 
-    def can_reject_task(
+    def _can_reject_task(
         self,
         task: Dict[str, Any],
         assign_last_annotator: bool,
@@ -131,25 +149,26 @@ class RejectTasks(AbstractCommandLineInterface):
 
         return True
 
-    def _cancel_acceptance(self, task: Dict[str, Any], my_account_id: str) -> Dict[str, Any]:
+    def _cancel_acceptance(self, task: Dict[str, Any]) -> Dict[str, Any]:
         request_body = {
             "status": "not_started",
-            "account_id": my_account_id,
+            "account_id": self.service.api.account_id,
             "last_updated_datetime": task["updated_datetime"],
         }
         content, _ = self.service.api.operate_task(task["project_id"], task["task_id"], request_body=request_body)
         return content
 
-    def reject_tasks_with_adding_comment(
+    def reject_task_with_adding_comment(
         self,
         project_id: str,
-        task_id_list: List[str],
-        commenter_user_id: str,
+        task_id: str,
+        project_input_data_type: InputDataType,
         inspection_comment: Optional[str] = None,
         assign_last_annotator: bool = True,
         assigned_annotator_user_id: Optional[str] = None,
         cancel_acceptance: bool = False,
-    ):
+        task_index: Optional[int] = None,
+    ) -> bool:
         """
         タスクを強制的に差し戻す
 
@@ -157,21 +176,11 @@ class RejectTasks(AbstractCommandLineInterface):
             project_id:
             task_id_list:
             inspection_comment: 検査コメントの中身
-            commenter_user_id: 検査コメントを付与して、タスクを差し戻すユーザのuser_id
             assign_last_annotator: Trueなら差し戻したタスクに対して、最後のannotation phaseを担当者を割り当てる
             assigned_annotator_user_id: 差し戻したタスクに割り当てるユーザのuser_id. assign_last_annotatorがTrueの場合、この引数は無視される。
 
         """
-
-        super().validate_project(project_id, [ProjectMemberRole.OWNER])
-        my_account_id = self.facade.get_my_account_id()
-        project, _ = self.service.api.get_project(project_id)
-        project_input_data_type = InputDataType(project["input_data_type"])
-
-        commenter_account_id = self.facade.get_account_id_from_user_id(project_id, commenter_user_id)
-        if commenter_account_id is None:
-            logger.error(f"検査コメントを付与するユーザ( {commenter_user_id} の account_idが見つかりませんでした。終了します。")
-            return
+        logging_prefix = f"{task_index+1} 件目" if task_index is not None else ""
 
         assigned_annotator_account_id = (
             self.facade.get_account_id_from_user_id(project_id, assigned_annotator_user_id)
@@ -179,92 +188,171 @@ class RejectTasks(AbstractCommandLineInterface):
             else None
         )
 
+        task, _ = self.service.api.get_task(project_id, task_id)
+
+        logger.debug(
+            f"{logging_prefix} : task_id = {task['task_id']}, "
+            f"status = {task['status']}, "
+            f"phase = {task['phase']}, "
+        )
+
+        if not self._can_reject_task(
+            task=task,
+            assign_last_annotator=assign_last_annotator,
+            assigned_annotator_user_id=assigned_annotator_user_id,
+            cancel_acceptance=cancel_acceptance,
+        ):
+            return False
+
+        if task["status"] == TaskStatus.COMPLETE.value and cancel_acceptance:
+            self._cancel_acceptance(task)
+
+        if inspection_comment is not None:
+            changed_task = self.change_to_working_status(project_id, task)
+            try:
+                # 検査コメントを付与する
+                self.add_inspection_comment(project_id, project_input_data_type, changed_task, inspection_comment)
+                logger.debug(f"{logging_prefix} : task_id = {task_id}, 検査コメントの付与 完了")
+
+            except requests.exceptions.HTTPError:
+                logger.warning(f"{logging_prefix} : task_id = {task_id} 検査コメントの付与に失敗", exc_info=True)
+                self.facade.change_to_break_phase(project_id, task_id)
+                return False
+
+        try:
+            # タスクを差し戻す
+            if assign_last_annotator:
+                # 最後のannotation phaseに担当を割り当てる
+                self.facade.reject_task_assign_last_annotator(project_id, task_id)
+                logger.info(f"{logging_prefix} : task_id = {task_id} のタスクを差し戻しました。タスクの担当者は直前の教師付フェーズの担当者。")
+                return True
+
+            else:
+                # 指定したユーザに担当を割り当てる
+                self.facade.reject_task(
+                    project_id,
+                    task_id,
+                    account_id=self.service.api.account_id,
+                    annotator_account_id=assigned_annotator_account_id,
+                )
+                str_annotator_user = f"タスクの担当者: {assigned_annotator_user_id}"
+                logger.info(f"{logging_prefix} : task_id = {task_id} の差し戻し完了. {str_annotator_user}")
+                return True
+
+        except requests.exceptions.HTTPError as e:
+            logger.warning(e)
+            logger.warning(f"{logging_prefix} : task_id = {task_id} タスクの差し戻しに失敗")
+
+            new_task = self.service.wrapper.get_task_or_none(project_id, task_id)
+            if new_task["status"] == TaskStatus.WORKING.value and new_task["account_id"] == self.service.api.account_id:
+                self.facade.change_to_break_phase(project_id, task_id)
+            return False
+
+    def reject_task_for_task_wrapper(
+        self,
+        tpl: Tuple[int, str],
+        project_id: str,
+        project_input_data_type: InputDataType,
+        inspection_comment: Optional[str] = None,
+        assign_last_annotator: bool = True,
+        assigned_annotator_user_id: Optional[str] = None,
+        cancel_acceptance: bool = False,
+    ) -> bool:
+        task_index, task_id = tpl
+        return self.reject_task_with_adding_comment(
+            project_id=project_id,
+            task_id=task_id,
+            task_index=task_index,
+            project_input_data_type=project_input_data_type,
+            inspection_comment=inspection_comment,
+            assign_last_annotator=assign_last_annotator,
+            assigned_annotator_user_id=assigned_annotator_user_id,
+            cancel_acceptance=cancel_acceptance,
+        )
+
+    def reject_task_list(
+        self,
+        project_id: str,
+        task_id_list: List[str],
+        inspection_comment: Optional[str] = None,
+        assign_last_annotator: bool = True,
+        assigned_annotator_user_id: Optional[str] = None,
+        cancel_acceptance: bool = False,
+        parallelism: Optional[int] = None,
+    ) -> None:
+
+        project, _ = self.service.api.get_project(project_id)
+        project_input_data_type = InputDataType(project["input_data_type"])
+
         logger.info(f"差し戻すタスク数: {len(task_id_list)}")
-        success_count = 0
 
-        for task_index, task_id in enumerate(task_id_list):
-            str_progress = annofabcli.utils.progress_msg(task_index + 1, len(task_id_list))
-
-            task, _ = self.service.api.get_task(project_id, task_id)
-
-            logger.debug(
-                f"{str_progress} : task_id = {task_id} の現状: status = {task['status']}, phase = {task['phase']}"
-            )
-            if not self.can_reject_task(
-                task=task,
+        if parallelism is not None:
+            partial_func = partial(
+                self.reject_task_for_task_wrapper,
+                project_id=project_id,
+                project_input_data_type=project_input_data_type,
+                inspection_comment=inspection_comment,
                 assign_last_annotator=assign_last_annotator,
                 assigned_annotator_user_id=assigned_annotator_user_id,
                 cancel_acceptance=cancel_acceptance,
-            ):
-                continue
+            )
+            with multiprocessing.Pool(parallelism) as pool:
+                result_bool_list = pool.map(partial_func, enumerate(task_id_list))
+                success_count = len([e for e in result_bool_list if e])
 
-            if task["status"] == TaskStatus.COMPLETE.value and cancel_acceptance:
-                self._cancel_acceptance(task=task, my_account_id=my_account_id)
+        else:
+            # 逐次処理
+            success_count = 0
+            for task_index, task_id in enumerate(task_id_list):
+                result = self.reject_task_with_adding_comment(
+                    project_id,
+                    task_id,
+                    task_index=task_index,
+                    project_input_data_type=project_input_data_type,
+                    inspection_comment=inspection_comment,
+                    assign_last_annotator=assign_last_annotator,
+                    assigned_annotator_user_id=assigned_annotator_user_id,
+                    cancel_acceptance=cancel_acceptance,
+                )
+                if result:
+                    success_count += 1
 
-            if inspection_comment is not None:
-                changed_operator = self.change_to_working_status(project_id, task, my_account_id)
-                # スリープする理由：担当者を変更したときは、少し待たないと検査コメントが登録できないため
-                if changed_operator:
-                    time.sleep(2)
+        logger.info(f"{success_count} / {len(task_id_list)} 件 タスクを差し戻しました。")
 
-                try:
-                    # 検査コメントを付与する
-                    self.add_inspection_comment(
-                        project_id, project_input_data_type, task, inspection_comment, commenter_account_id
-                    )
-                    logger.debug(f"{str_progress} : task_id = {task_id}, 検査コメントの付与 完了")
 
-                except requests.exceptions.HTTPError as e:
-                    logger.warning(e)
-                    logger.warning(f"{str_progress} : task_id = {task_id} 検査コメントの付与に失敗")
-                    self.facade.change_to_break_phase(project_id, task_id, my_account_id)
-                    continue
+class RejectTasks(AbstractCommandLineInterface):
+    @staticmethod
+    def validate(args: argparse.Namespace) -> bool:
+        COMMON_MESSAGE = "annofabcli task reject: error:"
 
-            try:
-                # タスクを差し戻す
-                if assign_last_annotator:
-                    # 最後のannotation phaseに担当を割り当てる
-                    self.facade.reject_task_assign_last_annotator(project_id, task_id, commenter_account_id)
-                    logger.info(f"{str_progress} : task_id = {task_id} のタスクを差し戻しました。タスクの担当者は直前の教師付フェーズの担当者。")
+        if args.parallelism is not None and not args.yes:
+            print(
+                f"{COMMON_MESSAGE} argument --parallelism: '--parallelism'を指定するときは、必ず'--yes'を指定してください。",
+                file=sys.stderr,
+            )
+            return False
 
-                else:
-                    # 指定したユーザに担当を割り当てる
-                    self.facade.reject_task(
-                        project_id,
-                        task_id,
-                        account_id=commenter_account_id,
-                        annotator_account_id=assigned_annotator_account_id,
-                    )
-                    str_annotator_user = f"タスクの担当者: {assigned_annotator_user_id}"
-                    logger.info(f"{str_progress} : task_id = {task_id} の差し戻し完了. {str_annotator_user}")
-
-                success_count += 1
-
-            except requests.exceptions.HTTPError as e:
-                logger.warning(e)
-                logger.warning(f"{str_progress} : task_id = {task_id} タスクの差し戻しに失敗")
-
-                new_task = self.service.wrapper.get_task_or_none(project_id, task_id)
-                if new_task["status"] == TaskStatus.WORKING.value and new_task["account_id"] == my_account_id:
-                    self.facade.change_to_break_phase(project_id, task_id, my_account_id)
-                continue
-
-        logger.info(f"{success_count} / {len(task_id_list)} 件 タスクの差し戻しに成功した")
+        return True
 
     def main(self):
         args = self.args
+        if not self.validate(args):
+            return
 
         task_id_list = annofabcli.common.cli.get_list_from_args(args.task_id)
-        user_id = self.service.api.login_user_id
         assign_last_annotator = not args.not_assign and args.assigned_annotator_user_id is None
-        self.reject_tasks_with_adding_comment(
+
+        super().validate_project(args.project_id, [ProjectMemberRole.OWNER])
+
+        main_obj = RejectTasksMain(self.service, all_yes=self.all_yes)
+        main_obj.reject_task_list(
             args.project_id,
             task_id_list,
-            commenter_user_id=user_id,
             inspection_comment=args.comment,
             assign_last_annotator=assign_last_annotator,
             assigned_annotator_user_id=args.assigned_annotator_user_id,
             cancel_acceptance=args.cancel_acceptance,
+            parallelism=args.parallelism,
         )
 
 
@@ -302,6 +390,10 @@ def parse_args(parser: argparse.ArgumentParser):
 
     parser.add_argument("--cancel_acceptance", action="store_true", help="受入完了状態を取り消して、タスクを差し戻します。")
 
+    parser.add_argument(
+        "--parallelism", type=int, help="使用するプロセス数（並列度）を指定してください。指定する場合は必ず'--yes'を指定してください。指定しない場合は、逐次的に処理します。"
+    )
+
     parser.set_defaults(subcommand_func=main)
 
 
